/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.bundle;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

/**
 * Loads properties files relative to a base directory as {@link Bundle}s
 */
public class PropertiesFileBundleLoader implements BundleLoader {
  private File baseDirectory;

  /** {@inheritDoc} */
  public PropertiesFileBundleLoader(File aBaseDirectory) {
    baseDirectory = aBaseDirectory;
  }

  /** {@inheritDoc} */
  public Bundle loadBundle(String aDirectory, String[] aParameters) {
    Properties properties = new Properties();
    String fileName = aDirectory;
    for (int i=0; i<aParameters.length; i++) {
      fileName = fileName + "_" + aParameters[i];
    }
    fileName = fileName + ".properties";

    File file = new File(baseDirectory, fileName);

    try {
      properties.load(new FileInputStream(file));
    }
    catch (IOException e) {
    }

    return new PropertiesBundle(properties);
  }
}
