/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.generator;

import mir.bundle.Bundle;
import mir.entity.adapter.EntityAdapterEngine;
import mir.entity.adapter.EntityAdapterModel;
import mir.util.generator.BundleGeneratorFunction;
import mircoders.global.MirGlobal;

import java.util.*;



public class GeneratorHelper {
  /**
   * Method to initialize the basic generation values for templates.  Does nothing which assumes a servlet context.
   */

  public static Map makeBasicGenerationData(Locale[] aLocales, String aBundle, String aDefaultBundle) throws GeneratorExc {
    try {
      Map result = new HashMap();
      MirGlobal.localizer().producerAssistant().initializeGenerationValueSet(result);

      EntityAdapterModel model = MirGlobal.localizer().dataModel().adapterModel();

      List languages = EntityAdapterEngine.retrieveAdapterList(model, "language", "", "id", -1, 0);

      List topics = EntityAdapterEngine.retrieveAdapterList(model, "topic", "", "id", -1, 0);

      List articleTypes  = EntityAdapterEngine.retrieveAdapterList(model, "articleType", "", "id", -1, 0);

      List commentStatuses  = EntityAdapterEngine.retrieveAdapterList(model, "commentStatus", "", "id", -1, 0);

      result.put("commentstatuses", commentStatuses);
      result.put("articletypes", articleTypes);
      result.put("languages", languages);
      result.put("topics", topics);

      List bundles = new ArrayList();
      for (int i=0; i<aLocales.length; i++) {
        bundles.add(MirGlobal.getBundleFactory().getBundle(aBundle, new String[] { aLocales[i].getLanguage()} ));
        bundles.add(MirGlobal.getBundleFactory().getBundle(aDefaultBundle, new String[] { aLocales[i].getLanguage()} ));
      }
      result.put("lang", new BundleGeneratorFunction((Bundle[]) bundles.toArray(new Bundle[0])));

      return result;
    }
    catch (Throwable t) {
      throw new GeneratorFailure(t);
    }
  }
}
