/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.log;

import mir.config.MirPropertiesConfiguration;

public class LoggerEngine {
  private static Logger loggerInstance;

  static {
    try {
      String loggerClass = MirPropertiesConfiguration.instance().getString("Log.LogClass");
      loggerInstance = (Logger) Class.forName(loggerClass).newInstance();
    }
    catch (java.lang.ClassNotFoundException cnfe) {
      System.err.println("LoggerEngine was not able to initialize: class not found");
      cnfe.printStackTrace(System.err);
    }
    catch (java.lang.InstantiationException ie) {
      System.err.println(
          "LoggerEngine was not able to initialize: could not initialize class");
      ie.printStackTrace(System.err);
    }
    catch (java.lang.IllegalAccessException iae) {
      System.err.println("LoggerEngine was not able to initialize: illegal access");
      iae.printStackTrace(System.err);
    }
  }

  public static void debug(Object o, String s) {
    loggerInstance.debug(o, s);
  }

  public static void info(Object o, String s) {
    loggerInstance.info(o, s);
  }

  public static void warn(Object o, String s) {
    loggerInstance.warn(o, s);
  }

  public static void warn(Object o, String s, Throwable anException) {
    loggerInstance.warn(o, s, anException);
  }

  public static void error(Object o, String s) {
    loggerInstance.error(o, s);
  }

  public static void error(Object o, String s, Throwable anException) {
    loggerInstance.error(o, s, anException);
  }

  public static void fatal(Object o, String s) {
    loggerInstance.fatal(o, s);
  }

  public static void reload() throws LoggerExc, LoggerFailure {
    loggerInstance.reload();
  }
}
