package mir.util.xml;

import java.util.Map;

import mir.util.ExceptionRoutines;

import org.xml.sax.InputSource;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

/**
 *
 * <p>Title: </p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: </p>
 * @author not attributable
 * @version 1.0
 */
class XMLSAXParserProvider implements XMLParserEngine.XMLParserProvider {
  private boolean nameSpaceAware;

  public XMLSAXParserProvider(boolean aNameSpaceAware) {
    nameSpaceAware = aNameSpaceAware;
  }

  public void parse(java.io.Reader aReader, XMLParserEngine.XMLParserReceiver aReceiver) throws XMLParserExc, XMLParserFailure {
    try {
      javax.xml.parsers.SAXParserFactory parserFactory = javax.xml.parsers.SAXParserFactory.newInstance();

      parserFactory.setNamespaceAware(true);
      parserFactory.setValidating(true);
      javax.xml.parsers.SAXParser parser = parserFactory.newSAXParser();

      parser.parse(new InputSource(aReader), new SAXHandler(aReceiver));
    }
    catch (org.xml.sax.SAXException e) {
      Throwable t = ExceptionRoutines.traceCauseException(e);

      if (t instanceof XMLParserExc) {
        throw (XMLParserExc) t;
      }

      if (t instanceof XMLParserFailure) {
        throw (XMLParserFailure) t;
      }

      if (t instanceof SAXParseException) {
        throw new XMLParserExc(t.getMessage());
      }

      throw new XMLParserFailure(t);
    }
    catch (Throwable t) {
      throw new XMLParserFailure(t);
    }
  }

  private class SAXHandler extends org.xml.sax.helpers.DefaultHandler {
    private XMLParserEngine.XMLParserReceiver receiver;

    public SAXHandler(XMLParserEngine.XMLParserReceiver aReceiver) throws XMLParserExc, XMLParserFailure {
      super();

      receiver = aReceiver;
      receiver.startDocument();
   }

    public void setDocumentLocator(final Locator aLocator) {
      receiver.setLocator(
          new XMLParserEngine.XMLLocator() {
            public int getLineNr() {
              return aLocator.getLineNumber();
            }

            public int getColumnNr() {
              return aLocator.getColumnNumber();
            }
          }
      );
    }

    public void startElement(String aUri, String aLocalName, String aQualifiedName, org.xml.sax.Attributes anAttributes) throws org.xml.sax.SAXException {
      try {
        Map attributes = new java.util.HashMap();

        XMLName tag;
        if (nameSpaceAware) {
          tag = new XMLName(aUri, XMLReaderTool.getPrefixFromQualifiedName(aQualifiedName), aLocalName);
          for (int i=0; i<anAttributes.getLength(); i++)
            attributes.put(
                new XMLName(anAttributes.getURI(i),
                            XMLReaderTool.getPrefixFromQualifiedName(anAttributes.getQName(i)),
                            anAttributes.getLocalName(i)),
                anAttributes.getValue(i));
        }
        else {
          tag = new XMLName(aUri, XMLReaderTool.getPrefixFromQualifiedName(aQualifiedName),
                      XMLReaderTool.getLocalNameFromQualifiedName(aQualifiedName));
          for (int i=0; i<anAttributes.getLength(); i++)
            attributes.put(
                new XMLName(anAttributes.getURI(i),
                           XMLReaderTool.getPrefixFromQualifiedName(anAttributes.getQName(i)),
                           XMLReaderTool.getLocalNameFromQualifiedName(anAttributes.getQName(i))),
                anAttributes.getValue(i));
        }

        receiver.startElement(tag, attributes);
      }
      catch (XMLParserExc e) {
        throw new org.xml.sax.SAXParseException(e.getMessage(), null, e);
      }
      catch (Exception e) {
        throw new SAXException(e);
      }
    }

    public void endElement(String aUri, String aLocalName, String aQualifiedName) throws org.xml.sax.SAXException {
      try
      {
        XMLName element = new XMLName(aUri, XMLReaderTool.getPrefixFromQualifiedName(aQualifiedName), aLocalName);

        receiver.endElement(element);
      }
      catch (XMLParserExc e) {
        throw new org.xml.sax.SAXParseException(e.getMessage(), null, e);
      }
      catch (Exception e) {
        throw new org.xml.sax.SAXException(e);
      }
    }

    public void endDocument() throws org.xml.sax.SAXException {
      try
      {
        receiver.endDocument();
      }
      catch (XMLParserExc e) {
        throw new org.xml.sax.SAXParseException(e.getMessage(), null, e);
      }
      catch (Exception e) {
        throw new org.xml.sax.SAXException(e);
      }
    }

    public void characters(char[] aBuffer, int aStart, int anEnd) throws org.xml.sax.SAXException {
      try {
        String text = new String(aBuffer, aStart, anEnd);

        receiver.text(text);
      }
      catch (XMLParserExc e) {
        throw new org.xml.sax.SAXParseException(e.getMessage(), null, e);
      }
      catch (Exception e) {
        throw new org.xml.sax.SAXException(e);
      }
    }
  }
}
