/*
 * Copyright (C) 2001, 2002 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License,
 * The Sun (tm) Java Advanced Imaging library (JAI), The Sun JIMI library
 * (or with modified versions of the above that use the same license as the above),
 * and distribute linked combinations including the two.  You must obey the
 * GNU General Public License in all respects for all of the code used other than
 * the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mircoders.media;

import mir.entity.Entity;
import mir.media.MediaExc;
import mir.media.MediaFailure;
import mir.media.MediaHandler;
import mir.misc.StringUtil;

import java.io.*;

public abstract class AbstractMediaHandler implements MediaHandler {
  protected InputStream getStorageInputStream(Entity aMedia, Entity aMediaType) throws MediaExc, MediaFailure {
    try {
      return new FileInputStream(getMediaStorageFile(aMedia, aMediaType));
    }
    catch (Throwable e) {
      throw new MediaFailure(e);
    }
  }

  protected OutputStream getStorageOutputStream(Entity aMedia, Entity aMediaType) throws MediaExc, MediaFailure {
    try {
      return new FileOutputStream(getMediaStoragePath(aMedia, aMediaType));
    }
    catch (Throwable e) {
      throw new MediaFailure(e);
    }
  }

  protected String getRelativeMediaStoragePath(Entity aMedia, Entity aMediaType) {
    String publishPath = aMedia.getFieldValue("publish_path");

    if (publishPath==null || publishPath.length()==0) {
      String extension = aMediaType.getFieldValue("name");
      String mediaFileName = aMedia.getId() + "." + extension;
      String date = aMedia.getFieldValue("date");
      String datePath = StringUtil.webdbDate2path(date);

      return datePath + "/" + mediaFileName;
    }

		return publishPath;
  }

  protected String getMediaStoragePath(Entity aMedia, Entity aMediaType) throws MediaExc, MediaFailure {
    return getBaseStoragePath() + "/" + getRelativeMediaStoragePath(aMedia, aMediaType);
  }

  protected final File getMediaStorageFile(Entity aMedia, Entity aMediaType) throws MediaExc, MediaFailure {
    return new File(getMediaStoragePath(aMedia, aMediaType));
  }

}
